@@ -197,7 +197,7 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
     def simulate_to_steady_state(
         self,
         tolerance: float = 1e-6,
-        simulation_kwargs: Dict[str, Any] = None,
+        simulation_kwargs: Dict[str, Any] | None = None,
         **integrator_kwargs: Dict[str, Any],
     ) -> Tuple[Optional[Array], Optional[Array]]:
         """Simulate the model."""
@@ -219,7 +219,7 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
 
     def get_results_array(
         self,
-        normalise: Union[float, ArrayLike] = None,
+        normalise: Union[float, ArrayLike] | None = None,
         concatenated: bool = True,
     ) -> Union[None, Array, List[Array]]:
         """Get simulation results."""
@@ -235,7 +235,7 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
 
     def get_results_dict(
         self,
-        normalise: Union[float, ArrayLike] = None,
+        normalise: Union[float, ArrayLike] | None = None,
         concatenated: bool = True,
     ) -> Union[None, Dict[str, Array], List[Dict[str, Array]]]:
         """Get simulation results."""
@@ -250,7 +250,7 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
 
     def get_results_df(
         self,
-        normalise: Union[float, ArrayLike] = None,
+        normalise: Union[float, ArrayLike] | None = None,
         concatenated: bool = True,
     ) -> Union[None, pd.DataFrame, List[pd.DataFrame]]:
         """Get simulation results."""
@@ -340,7 +340,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         y0: Optional[ArrayLike] = None,
         time: Optional[List[Array]] = None,
         results: Optional[List[Array]] = None,
-        parameters: List[Dict[str, float]] = None,
+        parameters: List[Dict[str, float]] | None = None,
     ) -> None:
         _BaseSimulator.__init__(self, model=model, integrator=integrator, y0=y0, time=time, results=results)
         self.full_results: Optional[List[Array]] = None
@@ -459,7 +459,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def simulate_to_steady_state(
         self,
         tolerance: float = 1e-8,
-        simulation_kwargs: Dict[str, Any] = None,
+        simulation_kwargs: Dict[str, Any] | None = None,
         **integrator_kwargs: Dict[str, Any],
     ) -> Tuple[Optional[Array], Optional[Array]]:
         """Simulate the model to steady state."""
@@ -490,7 +490,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def get_fluxes_array(
         self,
-        normalise: Union[float, ArrayLike] = None,
+        normalise: Union[float, ArrayLike] | None = None,
         concatenated: bool = True,
     ) -> Optional[Union[Array, List[Array]]]:
         """Get the model fluxes for the simulation."""
@@ -507,7 +507,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def get_fluxes_dict(
         self,
-        normalise: Union[float, ArrayLike] = None,
+        normalise: Union[float, ArrayLike] | None = None,
         concatenated: bool = True,
     ) -> Optional[Union[Dict[str, Array], List[Dict[str, Array]]]]:
         """Get the model fluxes for the simulation."""
@@ -520,7 +520,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def get_fluxes_df(
         self,
-        normalise: Union[float, ArrayLike] = None,
+        normalise: Union[float, ArrayLike] | None = None,
         concatenated: bool = True,
     ) -> Optional[Union[pd.DataFrame, List[pd.DataFrame]]]:
         """Get the model fluxes for the simulation."""
@@ -554,7 +554,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def get_full_results_array(
         self,
-        normalise: Union[float, ArrayLike] = None,
+        normalise: Union[float, ArrayLike] | None = None,
         concatenated: bool = True,
     ) -> Optional[Union[Array, List[Array]]]:
         """Get simulation results and derived compounds.
@@ -579,7 +579,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def get_full_results_dict(
         self,
-        normalise: Union[float, ArrayLike] = None,
+        normalise: Union[float, ArrayLike] | None = None,
         concatenated: bool = True,
     ) -> Optional[Union[Dict[str, Array], List[Dict[str, Array]]]]:
         """Get simulation results and derived compounds."""
@@ -593,7 +593,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def get_full_results_df(
         self,
-        normalise: Union[float, ArrayLike] = None,
+        normalise: Union[float, ArrayLike] | None = None,
         concatenated: bool = True,
     ) -> Optional[Union[pd.DataFrame, List[pd.DataFrame]]]:
         """Get simulation results and derived compounds."""
@@ -610,7 +610,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def get_variable(
         self,
         variable: str,
-        normalise: Union[float, ArrayLike] = None,
+        normalise: Union[float, ArrayLike] | None = None,
         concatenated: bool = True,
     ) -> Optional[Union[Array, List[Array]]]:
         """Get simulation results for a specific variable.
@@ -629,7 +629,7 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def get_variables(
         self,
         variables: List[str],
-        normalise: Union[float, ArrayLike] = None,
+        normalise: Union[float, ArrayLike] | None = None,
         concatenated: bool = True,
     ) -> Union[Array, List[Array]]:
         """Get simulation results for a specific variable."""
@@ -817,21 +817,21 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def plot_log(
         self,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
-        normalise: Union[float, ArrayLike] = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
+        normalise: Union[float, ArrayLike] | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         compounds = self.model.get_compounds()
         y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
@@ -862,21 +862,21 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def plot_semilog(
         self,
         log_axis: str = "y",
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
-        normalise: Union[float, ArrayLike] = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
+        normalise: Union[float, ArrayLike] | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         compounds = self.model.get_compounds()
         y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
@@ -910,21 +910,21 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def plot_derived(
         self,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
-        normalise: Union[float, ArrayLike] = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
+        normalise: Union[float, ArrayLike] | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         compounds = self.model.get_derived_compounds()
         y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
@@ -951,21 +951,21 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def plot_all(
         self,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
-        normalise: Union[float, ArrayLike] = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
+        normalise: Union[float, ArrayLike] | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         compounds = self.model.get_all_compounds()
         y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
@@ -993,21 +993,21 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def plot_selection(
         self,
         compounds: List[str],
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
-        normalise: Union[float, ArrayLike] = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
+        normalise: Union[float, ArrayLike] | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
         if y is None:
@@ -1034,24 +1034,24 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def plot_grid(
         self,
         compound_groups: List[List[str]],
-        ncols: int = None,
+        ncols: int | None = None,
         sharex: bool = True,
         sharey: bool = True,
-        xlabels: List[str] = None,
-        ylabels: List[str] = None,
-        normalise: Union[float, ArrayLike] = None,
+        xlabels: List[str] | None = None,
+        ylabels: List[str] | None = None,
+        normalise: Union[float, ArrayLike] | None = None,
         plot_titles: Optional[Iterable[str]] = None,
-        figure_title: str = None,
+        figure_title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axes]]:
         """Plot simulation results of the compound groups as a grid.
 
@@ -1088,20 +1088,20 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def plot_against_variable(
         self,
         variable: str,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = variable
@@ -1133,20 +1133,20 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def plot_derived_against_variable(
         self,
         variable: str,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = variable
@@ -1178,20 +1178,20 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def plot_all_against_variable(
         self,
         variable: str,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = variable
@@ -1224,20 +1224,20 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         self,
         compounds: Iterable[str],
         variable: str,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None | None = None,
+        subplot_kwargs: Dict[str, Any] | None | None = None,
+        plot_kwargs: Dict[str, Any] | None | None = None,
+        grid_kwargs: Dict[str, Any] | None | None = None,
+        legend_kwargs: Dict[str, Any] | None | None = None,
+        tick_kwargs: Dict[str, Any] | None | None = None,
+        label_kwargs: Dict[str, Any] | None | None = None,
+        title_kwargs: Dict[str, Any] | None | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = variable
@@ -1267,21 +1267,21 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def plot_fluxes(
         self,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
-        normalise: Union[float, ArrayLike] = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
+        normalise: Union[float, ArrayLike] | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         rate_names = cast(List[str], self.model.get_rate_names())
         y = self.get_fluxes_df(normalise=normalise, concatenated=True)
@@ -1310,21 +1310,21 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def plot_flux_selection(
         self,
         rate_names: List[str],
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
-        normalise: Union[float, ArrayLike] = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
+        normalise: Union[float, ArrayLike] | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         y = self.get_fluxes_df(normalise=normalise, concatenated=True)
         if y is None:
@@ -1352,24 +1352,24 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def plot_fluxes_grid(
         self,
         rate_groups: List[List[str]],
-        ncols: int = None,
+        ncols: int | None = None,
         sharex: bool = True,
         sharey: bool = True,
-        xlabels: List[str] = None,
-        ylabels: List[str] = None,
-        normalise: Union[float, ArrayLike] = None,
+        xlabels: List[str] | None = None,
+        ylabels: List[str] | None = None,
+        normalise: Union[float, ArrayLike] | None = None,
         plot_titles: Optional[Iterable[str]] = None,
-        figure_title: str = None,
+        figure_title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Array]]:
         """Plot simulation results of the compound groups as a grid.
 
@@ -1407,20 +1407,20 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
     def plot_fluxes_against_variable(
         self,
         variable: str,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = variable
@@ -1453,20 +1453,20 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         self,
         rate_names: List[str],
         variable: str,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = variable
@@ -1498,20 +1498,20 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         self,
         cpd1: str,
         cpd2: str,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         if xlabel is None:
             xlabel = cpd1
@@ -1545,21 +1545,21 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         cpd1: str,
         cpd2: str,
         cpd3: str,
-        xlabel: str = None,
-        ylabel: str = None,
-        zlabel: str = None,
-        title: str = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        zlabel: str | None = None,
+        title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         kwargs = _get_plot_kwargs(
             figure_kwargs=figure_kwargs,
@@ -1612,20 +1612,20 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         n: int,
         y0: Dict[str, float],
         t0: float = 0,
-        xlabel: str = None,
-        ylabel: str = None,
-        title: str = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         xlabel = cpd1 if xlabel is None else xlabel
         ylabel = cpd2 if ylabel is None else ylabel
@@ -1683,21 +1683,21 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         n: int,
         y0: Dict[str, float],
         t0: float = 0,
-        xlabel: str = None,
-        ylabel: str = None,
-        zlabel: str = None,
-        title: str = None,
+        xlabel: str | None = None,
+        ylabel: str | None = None,
+        zlabel: str | None = None,
+        title: str | None = None,
         grid: bool = True,
         tight_layout: bool = True,
         ax: Optional[Axis] = None,
-        figure_kwargs: Dict[str, Any] = None,
-        subplot_kwargs: Dict[str, Any] = None,
-        plot_kwargs: Dict[str, Any] = None,
-        grid_kwargs: Dict[str, Any] = None,
-        legend_kwargs: Dict[str, Any] = None,
-        tick_kwargs: Dict[str, Any] = None,
-        label_kwargs: Dict[str, Any] = None,
-        title_kwargs: Dict[str, Any] = None,
+        figure_kwargs: Dict[str, Any] | None = None,
+        subplot_kwargs: Dict[str, Any] | None = None,
+        plot_kwargs: Dict[str, Any] | None = None,
+        grid_kwargs: Dict[str, Any] | None = None,
+        legend_kwargs: Dict[str, Any] | None = None,
+        tick_kwargs: Dict[str, Any] | None = None,
+        label_kwargs: Dict[str, Any] | None = None,
+        title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         kwargs = _get_plot_kwargs(
             figure_kwargs=figure_kwargs,
