@@ -22,7 +22,7 @@ __all__ = [
     "plot_flux_response_coefficients",
 ]
 import math
-from typing import Dict, List, Optional, Tuple, Union, cast
+from typing import Any, Dict, List, Optional, Tuple, Union, cast
 
 import matplotlib.pyplot as plt
 import numpy as np
@@ -39,18 +39,12 @@ from ..models import Model
 from ..simulators import Simulator
 
 _DISPLACEMENT = 1e-4
+_DEFAULT_TOLERANCE = 1e-8
 
 
-def _find_steady_state(
-    *,
-    model: Model,
-    y0: Union[ArrayLike, Dict[str, float]],
-) -> Tuple[Optional[Array], Optional[Array]]:
-    """Simulate the system to steadt state."""
-    s = Simulator(model=model)
-    s.initialise(y0=y0, test_run=False)
-    t, y = s.simulate_to_steady_state()
-    return t, y
+###############################################################################
+# Non-steady state
+###############################################################################
 
 
 def get_compound_elasticity(
@@ -203,18 +197,51 @@ def get_parameter_elasticities_df(
     return pd.DataFrame(matrix, index=parameters, columns=model.get_rate_names())
 
 
+###############################################################################
+# Steady state
+###############################################################################
+
+
+def _find_steady_state(
+    *,
+    model: Model,
+    y0: Union[ArrayLike, Dict[str, float]],
+    tolerance: float,
+    simulation_kwargs: Dict[str, Any] | None,
+    **integrator_kwargs: Dict[str, Any],
+) -> Tuple[Optional[Array], Optional[Array]]:
+    """Simulate the system to steadt state."""
+    s = Simulator(model=model)
+    s.initialise(y0=y0, test_run=False)
+    t, y = s.simulate_to_steady_state(
+        tolerance=tolerance,
+        simulation_kwargs=simulation_kwargs,
+        **integrator_kwargs,
+    )
+    return t, y
+
+
 def get_response_coefficients(
     model: Model,
     parameter: str,
     y: Union[Dict[str, float], Array, List],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
+    tolerance: float = _DEFAULT_TOLERANCE,
+    simulation_kwargs: Dict[str, Any] | None = None,
+    **integrator_kwargs: Dict[str, Any],
 ) -> Tuple[Optional[Array], Optional[Array]]:
     """Get response of the steady state concentrations and fluxes to a change of the given parameter."""
     model = model.copy()
     old_value = model.get_parameter(parameter_name=parameter)
     if normalized:
-        t_ss, y_ss = _find_steady_state(model=model, y0=y)
+        t_ss, y_ss = _find_steady_state(
+            model=model,
+            y0=y,
+            tolerance=tolerance,
+            simulation_kwargs=simulation_kwargs,
+            **integrator_kwargs,
+        )
         if t_ss is None or y_ss is None:
             return None, None
         fluxes_array_norm = model.get_fluxes_array(y=y_ss, t=t_ss)
@@ -230,7 +257,13 @@ def get_response_coefficients(
         old_value * (1 - displacement),
     ]:
         model.update_parameter(parameter_name=parameter, parameter_value=new_value)
-        t_ss, y_ss = _find_steady_state(model=model, y0=y)
+        t_ss, y_ss = _find_steady_state(
+            model=model,
+            y0=y,
+            tolerance=tolerance,
+            simulation_kwargs=simulation_kwargs,
+            **integrator_kwargs,
+        )
         if t_ss is None or y_ss is None:
             return None, None
         fcd = model.get_full_concentration_dict(y_ss)
@@ -253,6 +286,9 @@ def get_response_coefficients_array(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
+    tolerance: float = _DEFAULT_TOLERANCE,
+    simulation_kwargs: Dict[str, Any] | None = None,
+    **integrator_kwargs: Dict[str, Any],
 ) -> Tuple[Array, Array]:
     """Get response of the steady state concentrations and fluxes to a change of the given parameter."""
     crcs = np.full(shape=(len(parameters), len(model.get_all_compounds())), fill_value=np.nan)
@@ -264,6 +300,9 @@ def get_response_coefficients_array(
             y=y,
             normalized=normalized,
             displacement=displacement,
+            tolerance=tolerance,
+            simulation_kwargs=simulation_kwargs,
+            **integrator_kwargs,
         )
         if crc is not None:
             crcs[i] = crc
@@ -278,6 +317,9 @@ def get_response_coefficients_df(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
+    tolerance: float = _DEFAULT_TOLERANCE,
+    simulation_kwargs: Dict[str, Any] | None = None,
+    **integrator_kwargs: Dict[str, Any],
 ) -> Tuple[pd.DataFrame, pd.DataFrame]:
     """Get response of the steady state concentrations and fluxes to a change of the given parameter."""
     crcs, frcs = get_response_coefficients_array(
@@ -286,6 +328,9 @@ def get_response_coefficients_df(
         y=y,
         normalized=normalized,
         displacement=displacement,
+        tolerance=tolerance,
+        simulation_kwargs=simulation_kwargs,
+        **integrator_kwargs,
     )
     crcs_df = pd.DataFrame(
         data=crcs,
@@ -306,10 +351,20 @@ def get_concentration_response_coefficient(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
+    tolerance: float = _DEFAULT_TOLERANCE,
+    simulation_kwargs: Dict[str, Any] | None = None,
+    **integrator_kwargs: Dict[str, Any],
 ) -> Optional[Array]:
     """Get response of the steady state concentrations to a change of the given parameter."""
     return get_response_coefficients(
-        model=model, parameter=parameter, y=y, normalized=normalized, displacement=displacement
+        model=model,
+        parameter=parameter,
+        y=y,
+        normalized=normalized,
+        displacement=displacement,
+        tolerance=tolerance,
+        simulation_kwargs=simulation_kwargs,
+        **integrator_kwargs,
     )[0]
 
 
@@ -319,6 +374,9 @@ def get_concentration_response_coefficients_array(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
+    tolerance: float = _DEFAULT_TOLERANCE,
+    simulation_kwargs: Dict[str, Any] | None = None,
+    **integrator_kwargs: Dict[str, Any],
 ) -> Array:
     """Get response of the steady state concentrations to a change of the given parameters."""
     return get_response_coefficients_array(
@@ -327,6 +385,9 @@ def get_concentration_response_coefficients_array(
         y=y,
         normalized=normalized,
         displacement=displacement,
+        tolerance=tolerance,
+        simulation_kwargs=simulation_kwargs,
+        **integrator_kwargs,
     )[0]
 
 
@@ -336,6 +397,9 @@ def get_concentration_response_coefficients_df(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
+    tolerance: float = _DEFAULT_TOLERANCE,
+    simulation_kwargs: Dict[str, Any] | None = None,
+    **integrator_kwargs: Dict[str, Any],
 ) -> pd.DataFrame:
     """Get response of the steady state concentrations to a change of the given parameters"""
     return get_response_coefficients_df(
@@ -344,6 +408,9 @@ def get_concentration_response_coefficients_df(
         y=y,
         normalized=normalized,
         displacement=displacement,
+        tolerance=tolerance,
+        simulation_kwargs=simulation_kwargs,
+        **integrator_kwargs,
     )[0]
 
 
@@ -353,10 +420,20 @@ def get_flux_response_coefficient(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
+    tolerance: float = _DEFAULT_TOLERANCE,
+    simulation_kwargs: Dict[str, Any] | None = None,
+    **integrator_kwargs: Dict[str, Any],
 ) -> Optional[Array]:
     """Get response of the steady state fluxes to a change of the given parameter."""
     return get_response_coefficients(
-        model=model, parameter=parameter, y=y, normalized=normalized, displacement=displacement
+        model=model,
+        parameter=parameter,
+        y=y,
+        normalized=normalized,
+        displacement=displacement,
+        tolerance=tolerance,
+        simulation_kwargs=simulation_kwargs,
+        **integrator_kwargs,
     )[1]
 
 
@@ -366,6 +443,9 @@ def get_flux_response_coefficients_array(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
+    tolerance: float = _DEFAULT_TOLERANCE,
+    simulation_kwargs: Dict[str, Any] | None = None,
+    **integrator_kwargs: Dict[str, Any],
 ) -> Array:
     """Get response of the steady state fluxes to a change of the given parameters."""
     return get_response_coefficients_array(
@@ -374,6 +454,9 @@ def get_flux_response_coefficients_array(
         y=y,
         normalized=normalized,
         displacement=displacement,
+        tolerance=tolerance,
+        simulation_kwargs=simulation_kwargs,
+        **integrator_kwargs,
     )[1]
 
 
@@ -383,6 +466,9 @@ def get_flux_response_coefficients_df(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
+    tolerance: float = _DEFAULT_TOLERANCE,
+    simulation_kwargs: Dict[str, Any] | None = None,
+    **integrator_kwargs: Dict[str, Any],
 ) -> pd.DataFrame:
     """Get response of the steady state fluxes to a change of the given parameters."""
     return get_response_coefficients_df(
@@ -391,6 +477,9 @@ def get_flux_response_coefficients_df(
         y=y,
         normalized=normalized,
         displacement=displacement,
+        tolerance=tolerance,
+        simulation_kwargs=simulation_kwargs,
+        **integrator_kwargs,
     )[1]
 
 
@@ -492,6 +581,8 @@ def plot_concentration_response_coefficients(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
+    tolerance: float = _DEFAULT_TOLERANCE,
+    simulation_kwargs: Dict[str, Any] | None = None,
     cmap: str = "RdBu_r",
     rows: list[str] | None = None,
     columns: list[str] | None = None,
@@ -503,6 +594,7 @@ def plot_concentration_response_coefficients(
     ylabel: str | None = None,
     ax: Optional[Axis] = None,
     cax: Optional[Axis] = None,
+    **integrator_kwargs: Dict[str, Any],
 ) -> Tuple[Figure, Axis, QuadMesh]:
     """Calculate and plot response of the steady state concentration to a change of the given parameters.
 
@@ -517,6 +609,9 @@ def plot_concentration_response_coefficients(
         y=y,
         normalized=normalized,
         displacement=displacement,
+        tolerance=tolerance,
+        simulation_kwargs=simulation_kwargs,
+        **integrator_kwargs,
     )
     return plot_coefficient_heatmap(
         df=df,
@@ -541,6 +636,8 @@ def plot_flux_response_coefficients(
     y: Dict[str, float],
     normalized: bool = True,
     displacement: float = _DISPLACEMENT,
+    tolerance: float = _DEFAULT_TOLERANCE,
+    simulation_kwargs: Dict[str, Any] | None = None,
     cmap: str = "RdBu_r",
     rows: list[str] | None = None,
     columns: list[str] | None = None,
@@ -552,6 +649,7 @@ def plot_flux_response_coefficients(
     ylabel: str | None = None,
     ax: Optional[Axis] = None,
     cax: Optional[Axis] = None,
+    **integrator_kwargs: Dict[str, Any],
 ) -> Tuple[Figure, Axis, QuadMesh]:
     """Calculate and plot response of the steady state fluxes to a change of the given parameters.
 
@@ -566,6 +664,9 @@ def plot_flux_response_coefficients(
         y=y,
         normalized=normalized,
         displacement=displacement,
+        tolerance=tolerance,
+        simulation_kwargs=simulation_kwargs,
+        **integrator_kwargs,
     )
     return plot_coefficient_heatmap(
         df=df,
